@@ -1,56 +1,50 @@
 from sqlite3 import NotSupportedError
 from typing import Sequence
 
+from .engine import Benchmarker, Engine, SimulBenchmarker, SimulEngine
+from .enums import SolverType
 from .histogram import HistogramBuilder
 from .scoring import Scorer
-from .simulation import Benchmarker, MultiSimulator, Simulator
-from .solver import (
-    DeepEntropySolver,
-    DeepMinimaxSolver,
-    EntropySolver,
-    MinimaxSolver,
-    QuordleSolver,
-    Solver,
-    SolverType,
-)
+from .simul_solver import MinimaxSimulSolver, SimulSolver
+from .solver import DeepEntropySolver, DeepMinimaxSolver, EntropySolver, MinimaxSolver, Solver
 from .views import BenchmarkView, NullRunView, RunView
 from .words import Dictionary, Word, load_dictionary
 
 
-def create_multi_simulator(
+def create_simul_engine(
     size: int,
     *,
     solver_type: SolverType = SolverType.MINIMAX,
     depth: int = 1,
-    extras: Sequence[Word | None] | None = None,
+    extras: Sequence[Word] | None = None,
     lazy_eval: bool = True,
     reporter: RunView | None = None,
-) -> MultiSimulator:
+) -> SimulEngine:
 
-    dictionary, scorer, histogram_builder, _, multi_solver = create_models(
+    dictionary, scorer, histogram_builder, _, simul_solver = create_models(
         size, solver_type=solver_type, depth=depth, extras=extras, lazy_eval=lazy_eval
     )
 
-    reporter = reporter or RunView(size)
-    return MultiSimulator(dictionary, scorer, histogram_builder, multi_solver, reporter)
+    reporter = reporter or RunView()
+    return SimulEngine(dictionary, scorer, histogram_builder, simul_solver, reporter)
 
 
-def create_simulator(
+def create_engine(
     size: int,
     *,
     solver_type: SolverType = SolverType.MINIMAX,
     depth: int = 1,
-    extras: Sequence[Word | None] | None = None,
+    extras: Sequence[Word] | None = None,
     lazy_eval: bool = True,
     reporter: RunView | None = None,
-) -> Simulator:
+) -> Engine:
 
     dictionary, scorer, histogram_builder, solver, _ = create_models(
         size, solver_type=solver_type, depth=depth, extras=extras, lazy_eval=lazy_eval
     )
 
-    reporter = reporter or RunView(size)
-    return Simulator(dictionary, scorer, histogram_builder, solver, reporter)
+    reporter = reporter or RunView()
+    return Engine(dictionary, scorer, histogram_builder, solver, reporter)
 
 
 def create_benchmarker(
@@ -58,19 +52,39 @@ def create_benchmarker(
     *,
     solver_type: SolverType = SolverType.MINIMAX,
     depth: int = 1,
-    extras: Sequence[Word | None] | None = None,
+    extras: Sequence[Word] | None = None,
 ) -> Benchmarker:
-    simulator = create_simulator(
+    engine = create_engine(
         size,
         solver_type=solver_type,
         depth=depth,
         extras=extras,
         lazy_eval=False,
-        reporter=NullRunView(size),
+        reporter=NullRunView(),
     )
 
     reporter = BenchmarkView()
-    return Benchmarker(simulator, reporter)
+    return Benchmarker(engine, reporter)
+
+
+def create_simul_benchmarker(
+    size: int,
+    *,
+    solver_type: SolverType = SolverType.MINIMAX,
+    depth: int = 1,
+    extras: Sequence[Word] | None = None,
+) -> SimulBenchmarker:
+    simul_engine = create_simul_engine(
+        size,
+        solver_type=solver_type,
+        depth=depth,
+        extras=extras,
+        lazy_eval=False,
+        reporter=NullRunView(),
+    )
+
+    reporter = BenchmarkView()
+    return SimulBenchmarker(simul_engine, reporter)
 
 
 def create_models(
@@ -78,9 +92,9 @@ def create_models(
     *,
     solver_type: SolverType = SolverType.MINIMAX,
     depth: int = 1,
-    extras: Sequence[Word | None] | None = None,
+    extras: Sequence[Word] | None = None,
     lazy_eval: bool = True,
-) -> tuple[Dictionary, Scorer, HistogramBuilder, Solver, QuordleSolver]:
+) -> tuple[Dictionary, Scorer, HistogramBuilder, Solver, SimulSolver]:
 
     dictionary = load_dictionary(size, extras=extras)
     all_words, potential_solns = dictionary.words
@@ -89,18 +103,19 @@ def create_models(
     histogram_builder = HistogramBuilder(scorer, all_words, potential_solns, lazy_eval)
 
     if solver_type == SolverType.MINIMAX:
-        solver = MinimaxSolver(histogram_builder)
+        minimax_solver = MinimaxSolver(histogram_builder)
         for _ in range(1, depth):
-            solver = DeepMinimaxSolver(histogram_builder, solver)
+            minimax_solver = DeepMinimaxSolver(histogram_builder, minimax_solver)
+        solver: Solver = minimax_solver
 
     elif solver_type == SolverType.ENTROPY:
-        solver = EntropySolver(histogram_builder)
+        entropy_solver = EntropySolver(histogram_builder)
         for _ in range(1, depth):
-            solver = DeepEntropySolver(histogram_builder, solver)
-
+            entropy_solver = DeepEntropySolver(histogram_builder, entropy_solver)
+        solver = entropy_solver
     else:
         raise NotSupportedError(f"Solver type {solver_type} not recognised.")
 
-    multi_solver = QuordleSolver(histogram_builder)
+    simul_solver: SimulSolver = MinimaxSimulSolver(histogram_builder)
 
-    return dictionary, scorer, histogram_builder, solver, multi_solver
+    return dictionary, scorer, histogram_builder, solver, simul_solver
